summaryrefslogtreecommitdiff
path: root/libguile/continuations.c
diff options
context:
space:
mode:
authorAndy Wingo <wingo@pobox.com>2010-02-07 14:16:54 +0100
committerAndy Wingo <wingo@pobox.com>2010-02-08 13:35:06 +0100
commit997659f898d94abccdcba3c444b84e3c6f6e963e (patch)
tree64f1ab2f9657b5f27d7cca16deddece915018dfe /libguile/continuations.c
parentbabfc7b2c3fce452aa12fed8d89cd3fbc81e8cc8 (diff)
downloadguile-997659f898d94abccdcba3c444b84e3c6f6e963e.tar.gz
make scm_make_continuation internal
* libguile/continuations.h: * libguile/continuations.c (scm_i_make_continuation): Change from scm_make_continuation, and make internal. * libguile/vm-i-system.c (call/cc, tail-call/cc): Adapt callers. * test-suite/standalone/test-unwind.c (check_cont_body): Adapt a test. * doc/ref/api-control.texi (Continuations): Update docs.
Diffstat (limited to 'libguile/continuations.c')
-rw-r--r--libguile/continuations.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/libguile/continuations.c b/libguile/continuations.c
index e8e91d1ea..6caceca53 100644
--- a/libguile/continuations.c
+++ b/libguile/continuations.c
@@ -60,7 +60,7 @@ static scm_t_bits tc16_continuation;
/* scm_make_continuation will return a procedure whose objcode contains an
instruction to reinstate the continuation. Here, as in gsubr.c and smob.c, we
define the form of that trampoline function.
*/
@@ -189,9 +189,9 @@ continuation_print (SCM obj, SCM port, scm_print_state *state SCM_UNUSED)
/* this may return more than once: the first time with the escape
procedure, then subsequently with the value to be passed to the
continuation. */
-#define FUNC_NAME "scm_make_continuation"
+#define FUNC_NAME "scm_i_make_continuation"
SCM
-scm_make_continuation (int *first)
+scm_i_make_continuation (int *first)
{
scm_i_thread *thread = SCM_I_CURRENT_THREAD;
SCM cont;
@@ -60,7 +60,7 @@ static scm_t_bits tc16_continuation;
-/* scm_make_continuation will return a procedure whose objcode contains an
+/* scm_i_make_continuation will return a procedure whose objcode contains an
instruction to reinstate the continuation. Here, as in gsubr.c and smob.c, we
define the form of that trampoline function.